@@ -23,6 +23,8 @@ SOFTWARE.
 
 #include <stdio.h>
 #include <ctype.h>
+#include <signal.h>
+
 #ifndef VMS
 #include <X11/Xatom.h>
 #include <X11/Xos.h>
@@ -35,10 +37,28 @@ SOFTWARE.
 static Bool     drawToFakeServer = False;
 static Pixmap   tileToQuery     = None;
 
+typedef struct _RopNames { char	*name; int  rop; } RopNameRec, *RopNamePtr;
+
+RopNameRec ropNames[] = {
+	"clear",    	GXclear,	/* 0 */
+	"and",		GXand,		/* src AND dst */
+	"andReverse",	GXandReverse,	/* src AND NOT dst */
+	"copy",		GXcopy,		/* src */
+	"andInverted",	GXandInverted,	/* NOT src AND dst */
+	"noop",		GXnoop,		/* dst */
+	"xor",		GXxor,		/* src XOR dst */
+	"or",		GXor,		/* src OR dst */
+	"nor",		GXnor,		/* NOT src AND NOT dst */
+	"equiv",	GXequiv,	/* NOT src XOR dst */
+	"invert",	GXinvert,	/* NOT dst */
+	"orReverse",	GXorReverse,	/* src OR NOT dst */
+	"copyInverted",	GXcopyInverted,	/* NOT src */
+	"orInverted",	GXorInverted,	/* NOT src OR dst */
+	"nand",		GXnand,		/* NOT src OR NOT dst */
+	"set",		GXset,		/* 1 */
+};
 
 static Bool     labels		= False;
-static Bool     xorMode		= False;
-static Bool     bothModes       = False;
 static int      repeat		= 5;
 static int	seconds		= 5;
 
@@ -50,9 +70,17 @@ static double syncTime = 0.0;
 static int saveargc;
 static char **saveargv;
 
+static int  numRops = 1;
+static int  rops[16] = { GXcopy };
+static int  numPlanemasks = 1;
+static unsigned long planemasks[256] = { (unsigned long)~0 };
+
 static char *foreground = NULL;
 static char *background = NULL;
 
+static int numSubWindows = 7;
+static int subWindows[] = {4, 16, 25, 50, 75, 100, 200, 0};
+
 static int  fixedReps = 0;
 
 static Bool *doit;
@@ -65,6 +93,13 @@ static XRectangle ws[] = {  /* Clip rectangles */
 };
 #define MAXCLIP     (sizeof(ws) / sizeof(ws[0]))
 static Window clipWindows[MAXCLIP];
+static Colormap cmap;
+static int depth = -1;  /* -1 means use default depth */
+
+/* ScreenSaver state */
+static XParmRec    xparms;
+static int ssTimeout, ssInterval, ssPreferBlanking, ssAllowExposures;
+
 
 /************************************************
 *	    time related stuff			*
@@ -240,6 +275,41 @@ char *Get_Display_Name(pargc, argv)
 }
 
 
+/* 
+ * GetVersion (argc, argv) Look for -v1.2.
+ * If found remove it from command line.  Don't go past a lone _.
+ */
+
+Version GetVersion(pargc, argv)
+    int     *pargc;  /* MODIFIED */
+    char    **argv; /* MODIFIED */
+{
+    int     argc = *pargc;
+    char    **pargv = argv+1;
+    Version version = VERSION1_3;
+    int     i;
+
+    for (i = 1; i != argc; i++) {
+	char *arg = argv[i];
+
+	if (!strcmp (arg, "-v1.2")) {
+	    version = VERSION1_2;
+	    *pargc -= 1;
+	    continue;
+	}
+	if (!strcmp(arg,"-")) {
+	    while (i<argc)  *pargv++ = argv[i++];
+	    break;
+	}
+	*pargv++ = arg;
+    }
+
+    *pargv = NULL;
+    return (version);
+}
+
+
+
 /*
  * Open_Display: Routine to open a display with correct error handling.
  */
@@ -259,6 +329,18 @@ Display *Open_Display(display_name)
     return(d);
 }
 
+
+void Cleanup(sig, code, context) {
+    int sig, code;
+    struct sigcontext *scp;
+
+    fflush(stdout);
+    XSetScreenSaver(xparms.d, ssTimeout, ssInterval, ssPreferBlanking,
+	ssAllowExposures);
+    exit(sig);
+}
+
+
 /************************************************
 *		Performance stuff		*
 ************************************************/
@@ -270,20 +352,25 @@ void usage()
     int     i = 0;
     static char *help_message[] = {
 "where options include:",
-"    -display host:dpy		the X server to contact",
-"    -sync			do the tests in synchronous mode",
-"    -repeat <n>		do tests <n> times (default = 5)",
-"    -time <s>			do tests for <s> seconds each (default = 5)",
-/*"    -draw			draw after each test -- pmax only",*/
-"    -all			do all tests",
-"    -range <test1>[,<test2>]	like all, but do <test1> to <test2>",
-"    -labels			generate test labels for use by x11perffill",
-"    -fg			the foreground color to use",
-"    -bg		        the background color to use",
-"    -xor			use GXxor mode to draw",
-"    -both			use both GXcopy and GXxor mode to draw",
-"    -reps <n>			fix the rep count (default = auto scale)",
-"    -subs <s0 s1 ...>		a list of the number of sub-windows to use",
+"    -v1.2                     perform only v1.2 tests using old semantics",
+"    -display <host:display>   the X server to contact",
+"    -sync                     do the tests in synchronous mode",
+"    -pack                     pack rectangles right next to each other",
+"    -repeat <n>               do tests <n> times (default = 5)",
+"    -time <s>                 do tests for <s> seconds each (default = 5)",
+/*
+"    -draw                     draw after each test -- pmax only",
+*/
+"    -all                      do all tests",
+"    -range <test1>[,<test2>]  like all, but do <test1> to <test2>",
+"    -labels                   generate test labels for use by fillblnk",
+"    -fg                       the foreground color to use",
+"    -bg                       the background color to use",
+"    -rop <rop0 rop1 ...>      use the given rops to draw (default = GXcopy)",
+"    -pm <pm0 pm1 ...>         use the given planemasks to draw (default = ~0)",
+"    -depth <depth>            use a visual with <depth> planes per pixel",
+"    -reps <n>                 fix the rep count (default = auto scale)",
+"    -subs <s0 s1 ...>         a list of the number of sub-windows to use",
 NULL};
 
     fflush(stdout);
@@ -292,9 +379,10 @@ NULL};
 	fprintf(stderr, "%s\n", *cpp);
     }
     while (test[i].option != NULL) {
-        fprintf(stderr, "    %-28s   %s\n",
-		test[i].option, test[i].label);
-        i++;
+	if (test[i].versions & xparms.version ) {
+	    fprintf(stderr, "    %-24s   %s\n",	test[i].option, test[i].label);
+	}
+	i++;
     }
     fprintf(stderr, "\n");
     
@@ -350,7 +438,8 @@ void DoHardwareSync(xp, p, reps)
 
 static Test syncTest = {
     "syncTime", "Internal test for finding how long HardwareSync takes",
-    NullInitProc, DoHardwareSync, NullProc, NullProc, NONXOR, 0,
+    NullInitProc, DoHardwareSync, NullProc, NullProc, 
+    VALL, NONROP, 0,
     {1}
 };
 
@@ -373,13 +462,16 @@ static Window CreatePerfWindow(xp, x, y, width, height)
     su = XPlanesOfScreen(s);
     printf("Planes of screen returns %d\n", su);
 */
+    xswa.background_pixel = xp->background;
+    xswa.border_pixel = xp->foreground;
+    xswa.colormap = cmap;
     xswa.override_redirect = True;
     xswa.backing_store = False;
     xswa.save_under = False;
-    w = XCreateSimpleWindow (xp->d, DefaultRootWindow (xp->d),
-	x, y, width, height, 1, xp->foreground, xp->background);
-    XChangeWindowAttributes (xp->d, w, 
-	    CWOverrideRedirect | CWSaveUnder | CWBackingStore, &xswa);
+    w = XCreateWindow(xp->d, DefaultRootWindow(xp->d), x, y, width, height, 1,
+        xp->vinfo.depth, CopyFromParent, xp->vinfo.visual,
+	CWBackPixel | CWBorderPixel | CWColormap | CWOverrideRedirect 
+	| CWBackingStore | CWSaveUnder, &xswa);
     XMapWindow (xp->d, w);
     return w;
 }
@@ -420,9 +512,12 @@ double DoTest(xp, test, reps)
     int     reps;
 {
     double  time;
-    int     ret_width, ret_height;
+    unsigned int ret_width, ret_height;
 
-    HardwareSync (xp);
+    /* Tell screen-saver to restart counting again.  See comments below for the
+       XSetScreenSaver call. */
+    XForceScreenSaver(xp->d, ScreenSaverReset);
+    HardwareSync (xp); 
     InitTimes ();
     (*test->proc) (xp, &test->parms, reps);
     HardwareSync(xp);
@@ -475,7 +570,6 @@ int CalibrateTest(xp, test, seconds, usecperobj)
 	(*test->proc) (xp, &test->parms, reps);
 	HardwareSync(xp);
 	usecs = ElapsedTime(syncTime);
-	(*test->passCleanup) (xp, &test->parms);
 	(*test->cleanup) (xp, &test->parms);
 	DestroyClipWindows(xp, test->clips);
 
@@ -511,37 +605,42 @@ int CalibrateTest(xp, test, seconds, usecperobj)
     return reps;
 } /* CalibrateTest */
 
-
-void CreatePerfGCs(xp, func)
+void CreatePerfGCs(xp, func, pm)
     XParms  xp;
     int     func;
+    unsigned long   pm;
 {
-    XGCValues gcv;
-
-    gcv.graphics_exposures = False;
+    XGCValues gcvfg, gcvbg;
+    unsigned long	fg, bg;
 
+    fg = xp->foreground;
+    bg = xp->background;
+    gcvfg.graphics_exposures = False;
+    gcvbg.graphics_exposures = False;
+    gcvfg.plane_mask = pm;
+    gcvbg.plane_mask = pm;
+    gcvfg.function = func;
+    gcvbg.function = func;
+    
     if (func == GXxor) {
-	gcv.function = GXxor;
-	gcv.foreground = xp->background ^ xp->foreground;
-	gcv.background = xp->background;
-        xp->fggc = XCreateGC(xp->d, xp->w, 
-	    GCForeground | GCBackground | GCGraphicsExposures | GCFunction,
-	    &gcv);
-        xp->bggc = XCreateGC(xp->d, xp->w, 
-	    GCForeground | GCBackground | GCGraphicsExposures | GCFunction,
-	    &gcv);
+	/* Make test look good visually if possible */
+	gcvbg.foreground = gcvfg.foreground = bg ^ fg;
+	gcvbg.background = gcvfg.background = bg;
     } else {
-	gcv.foreground = xp->foreground;
-	gcv.background = xp->background;
-	xp->fggc = XCreateGC(xp->d, xp->w, 
-		GCForeground | GCBackground | GCGraphicsExposures, &gcv);
-	gcv.foreground = xp->background;
-	gcv.background = xp->foreground;
-	xp->bggc = XCreateGC(xp->d, xp->w, 
-		GCForeground | GCBackground | GCGraphicsExposures, &gcv);
+	gcvfg.foreground = fg;
+	gcvfg.background = bg;
+	gcvbg.foreground = bg;
+	gcvbg.background = fg;
     }
+    xp->fggc = XCreateGC(xp->d, xp->w,
+	GCForeground | GCBackground | GCGraphicsExposures
+      | GCFunction | GCPlaneMask, &gcvfg);
+    xp->bggc = XCreateGC(xp->d, xp->w, 
+	GCForeground | GCBackground | GCGraphicsExposures
+      | GCFunction | GCPlaneMask, &gcvbg);
 }
 
+
 void DestroyPerfGCs(xp)
     XParms(xp);
 {
@@ -555,11 +654,8 @@ int AllocateColor(display, name, pixel)
     int		pixel;
 {
     XColor      color;
-    Colormap    cmap;
 
     if (name != NULL) {
-	cmap = XDefaultColormap(display, DefaultScreen(display));
-
 	/* Try to parse color name */
 	if (XParseColor(display, cmap, name, &color)) {
 	    if (XAllocColor(display, cmap, &color)) {
@@ -591,24 +687,25 @@ void DisplayStatus(d, message, test)
 }
 
 
-void ProcessTest(xp, test, func, label)
+void ProcessTest(xp, test, func, pm, label)
     XParms  xp;
     Test    *test;
     int     func;
+    unsigned long   pm;
     char    *label;
 {
     double  time, totalTime;
-    int     reps;
+    int     reps, fooreps;
     int     j;
 
-    CreatePerfGCs(xp, func);
+    CreatePerfGCs(xp, func, pm);
     DisplayStatus(xp->d, "Calibrating", label);
     reps = CalibrateTest(xp, test, seconds, &time);
     if (reps != 0) {
 	DisplayStatus(xp->d, "Testing", label);
 	XDestroySubwindows(xp->d, xp->w);
 	XClearWindow(xp->d, xp->w);
-	(void)(*test->init) (xp, &test->parms, reps);
+	reps = (*test->init) (xp, &test->parms, reps);
 	/* Create clip windows if requested */
 	CreateClipWindows(xp, test->clips);
 
@@ -640,18 +737,17 @@ main(argc, argv)
     char **argv;
 
 {
-    int		i, j;
+    int		i, j, n, skip;
     int		numTests;       /* Even though the linker knows, we don't. */
     char	hostname[100];
     char	*displayName;
-    XParmRec    xparms;
     Bool	foundOne = False;
     Bool	synchronous = False;
     XGCValues	tgcv;
     int		screen;
-
-    /* ScreenSaver state */
-    int ssTimeout, ssInterval, ssPreferBlanking, ssAllowExposures;
+    int		rop, pm;
+    XVisualInfo *vinfolist, vinfotempl;
+    unsigned long vmask;
 
     /* Save away argv, argc, for usage to print out */
     saveargc = argc;
@@ -661,6 +757,7 @@ main(argc, argv)
     }
 
     xparms.pack = False;
+    xparms.version = VERSION1_3;
 
     /* Count number of tests */
     ForEachTest(numTests);
@@ -669,6 +766,7 @@ main(argc, argv)
     /* Parse arguments */
     program_name = argv[0];
     displayName = Get_Display_Name (&argc, argv);
+    xparms.version = GetVersion(&argc, argv);
     for (i = 1; i != argc; i++) {
 	if (strcmp (argv[i], "-all") == 0) {
 	    ForEachTest (j)
@@ -694,11 +792,13 @@ main(argc, argv)
 		cp2 = "-";
 	    }
 	    ForEachTest (j) {
-		if (strcmp (cp1, (test[j].option) + 1) == 0) {
+		if (strcmp (cp1, (test[j].option) + 1) == 0 &&
+		    (test[j].versions & xparms.version)) {
 		    int k = j;
 		    do {
 			doit[k] = True;
 		    } while (strcmp(cp2, (test[k].option + 1)) != 0 &&
+			     (test[k].versions & xparms.version) &&
 			     test[++k].option != NULL);
 		    if (*cp2 != '-' && test[k].option == NULL)
 			usage();
@@ -715,54 +815,65 @@ main(argc, argv)
 	} else if (strcmp (argv[i], "-draw") == 0) {
 	    drawToFakeServer = True;
 	} else if (strcmp (argv[i], "-repeat") == 0) {
+	    i++;
 	    if (argc <= i)
 		usage ();
-	    repeat = atoi (argv[++i]);
+	    repeat = atoi (argv[i]);
 	    if (repeat <= 0)
 	       usage ();
 	} else if (strcmp (argv[i], "-time") == 0) {
+	    i++;
 	    if (argc <= i)
 		usage ();
-	    seconds = atoi (argv[++i]);
+	    seconds = atoi (argv[i]);
 	    if (seconds <= 0)
 	       usage ();
 	} else if (strcmp(argv[i], "-fg") == 0) {
+	    i++;
 	    if (argc <= i)
 		usage ();
-	    i++;
 	    foreground = argv[i];
         } else if (strcmp(argv[i], "-bg") == 0) {
-	    if (argc <= i)
-		usage ();
 	    i++;
-	    background = argv[i];
-	} else if (strcmp(argv[i], "-xor") == 0) {
-	    xorMode = True;
-	} else if (strcmp(argv[i], "-both") == 0) {
-	    bothModes = True;
-	} else if (strcmp(argv[i], "-reps") == 0) {
 	    if (argc <= i)
 		usage ();
-	    fixedReps = atoi (argv[++i]);
+	    background = argv[i];
+	} else if (strcmp(argv[i], "-rop") == 0) {
+	    skip = GetRops (i+1, argc, argv, rops, &numRops);
+	    i += skip;
+	} else if (strcmp(argv[i], "-pm") == 0) {
+	    skip = GetNumbers (i+1, argc, argv, planemasks, &numPlanemasks);
+	    i += skip;
+	} else if (strcmp(argv[i], "-xor") == 0) {
+	    numRops = 1;
+	    rops[0] = GXxor;
+	} else if (strcmp (argv[i], "-both") == 0) {
+	    numRops = 2;
+	    rops[0] = GXcopy;
+	    rops[1] = GXxor;
+	} else if (strcmp(argv[i], "-reps") == 0) {
+	    i++;
+	    if (argc <= i)
+		usage ();
+	    fixedReps = atoi (argv[i]);
 	    if (fixedReps <= 0)
 		usage ();
-	} else if (strcmp(argv[i], "-subs") == 0) {
-	    int	j = 0;
-	    if (argc <= i)
-		usage ();
+        } else if (strcmp(argv[i], "-depth") == 0) {
 	    i++;
-	    while (i < argc && isdigit (argv[i][0]))
-	    {
-		if (subs[j] != 0) {
-		    subs[j] = atoi (argv[i++]);
-		    j++;
-		}
-		i++;
-	    }
-	    --i;
-	} else {
+	    if (argc <= i)
+                usage ();
+            depth = atoi(argv[i]);
+            if (depth <= 0)
+		usage ();
+	} else if (strcmp(argv[i], "-subs") == 0) {
+	    skip = GetNumbers (i+1, argc, argv, subWindows, &numSubWindows);
+	    i += skip;
+/*	} else if (strcmp(argv[i], "-v1.2") == 0) {
+	    xparms.version = VERSION1_2;
+*/	} else {
 	    ForEachTest (j) {
-		if (strcmp (argv[i], test[j].option) == 0) {
+		if (strcmp (argv[i], test[j].option) == 0 &&
+		    (test[j].versions & xparms.version)) {
 		    doit[j] = True;
 		    goto LegalOption;
 		}
@@ -778,25 +889,38 @@ main(argc, argv)
 	   assemble data from different x11perf runs into a nice format */
 	ForEachTest (i) {
 	    int child;
-	    if (doit[i]) {
+	    if (doit[i] && (test[i].versions & xparms.version)) {
 		switch (test[i].testType) {
-		    case NONXOR:
+		    case NONROP:
 			printf ("%s\n", test[i].label);
 			break;
     
-		    case XOR:
-			if (!xorMode || bothModes) {
-			    printf ("%s\n", test[i].label);
-			}
-			if (xorMode || bothModes) {
-			    printf("(XOR) %s\n", test[i].label);
-			}
+		    case ROP:
+			/* Run it through all specified rops and planemasks */
+			for (rop = 0; rop < numRops; rop++) {
+			    for (pm = 0; pm < numPlanemasks; pm++) {
+				if (planemasks[pm] == ~0) {
+				    if (rops[rop] == GXcopy) {
+					printf ("%s\n", test[i].label);
+				    } else {
+					printf ("(%s) %s\n",
+					    ropNames[rops[rop]].name,
+					    test[i].label);
+				    }
+				} else {
+				    printf ("(%s 0x%x) %s\n",
+					    ropNames[rops[rop]].name,
+					    planemasks[pm],
+					    test[i].label);
+				}
+			    } /* for pm */
+			} /* for rop */
 			break;
 		    
 		    case WINDOW:
-			for (child = 0; subs[child] != 0; child++) {
+			for (child = 0; child != numSubWindows; child++) {
 			    printf ("%s (%d kids)\n",
-				test[i].label, subs[child]);
+				test[i].label, subWindows[child]);
 			}
 			break;
 		} /* switch */
@@ -808,7 +932,49 @@ main(argc, argv)
     if (!foundOne)
 	usage ();
     xparms.d = Open_Display (displayName);
-    printf("x11perf - X11 performance program, version 1.2\n");
+    screen = DefaultScreen(xparms.d);
+
+    /* get visual info of default visual */
+    vmask = VisualIDMask | VisualScreenMask;
+    vinfotempl.visualid = XVisualIDFromVisual(XDefaultVisual(xparms.d, screen));
+    vinfotempl.screen = screen;
+    vinfolist = XGetVisualInfo(xparms.d, vmask, &vinfotempl, &n);
+    if (!vinfolist || n != 1) {
+	fprintf (stderr, "%s: can't get visual info of default visual\n",
+	    program_name);
+	exit(1);
+    }
+
+    if (depth == -1) {
+	/* use the default visual and colormap */
+	xparms.vinfo = *vinfolist;
+	cmap = XDefaultColormap(xparms.d, screen);
+    } else {
+	/* find the specified visual */
+	vmask = VisualDepthMask | VisualScreenMask;
+	vinfotempl.depth = depth;
+	vinfotempl.screen = screen;
+	vinfolist = XGetVisualInfo(xparms.d, vmask, &vinfotempl, &n);
+	if (!vinfolist) {
+	    fprintf (stderr, "%s: can't find a visual of depth %d\n",
+		program_name, depth);
+	    exit(1);
+	}
+	xparms.vinfo = *vinfolist;  /* use the first one in list */
+	if (xparms.vinfo.visualid ==
+	    XVisualIDFromVisual(XDefaultVisual(xparms.d, screen))) {
+	    /* matched visual is same as default visual */
+	    cmap = XDefaultColormap(xparms.d, screen);
+	} else {
+	    cmap = XCreateColormap(xparms.d, DefaultRootWindow(xparms.d),
+		xparms.vinfo.visual, AllocNone);
+	    /* since this is not default cmap, must force color allocation */
+	    if (!foreground) foreground = "Black";
+	    if (!background) background = "White";
+	}
+    }
+
+    printf("x11perf - X11 performance program, version 1.3\n");
 #ifndef VMS
     gethostname (hostname, 100);
     printf ("%s server on %s\nfrom %s\n",
@@ -817,17 +983,23 @@ main(argc, argv)
     printf ("%s server on %s\n",
 	    ServerVendor (xparms.d), DisplayString (xparms.d));
 #endif
-    screen = DefaultScreen (xparms.d);
     PrintTime ();
 
     /* Force screen out of screen-saver mode, grab current data, and set
-       time to blank to 8 hours.  This finesses various problems if you
-       try to turn it off completely.  As long as the tests run to 
+       time to blank to 8 hours.  We should just be able to turn the screen-
+       saver off, but this causes problems on some servers.  We also reset
+       the screen-saver timer each test, as 8 hours is about the maximum time
+       we can use, and that isn't long enough for some X terminals using a
+       serial protocol to finish all the tests.  As long as the tests run to 
        completion, the old screen-saver values are restored. */
     XForceScreenSaver(xparms.d, ScreenSaverReset);
     XGetScreenSaver(xparms.d, &ssTimeout, &ssInterval, &ssPreferBlanking,
 	&ssAllowExposures);
-    XSetScreenSaver(xparms.d, 8 * 3600, ssInterval, ssPreferBlanking,
+    (void) signal(SIGINT, Cleanup); /* ^C */
+    (void) signal(SIGQUIT, Cleanup);
+    (void) signal(SIGTERM, Cleanup);
+    (void) signal(SIGHUP, Cleanup);
+    XSetScreenSaver(xparms.d, 8 * 3600, ssInterval, ssPreferBlanking, 
 	ssAllowExposures);
 
     if (drawToFakeServer) {
@@ -865,35 +1037,45 @@ main(argc, argv)
 	int child;
 	char label[200];
 
-	if (doit[i]) {
+	if (doit[i] && (test[i].versions & xparms.version)) {
 	    switch (test[i].testType) {
-	        case NONXOR:
+	        case NONROP:
 		    /* Simplest...just run it once */
 		    strcpy (label, test[i].label);
-		    ProcessTest(&xparms, &test[i], GXcopy, label);
+		    ProcessTest(&xparms, &test[i], GXcopy, ~0, label);
 		    break;
 
-		case XOR:
-		    /* Run it once or twice */
-		    if (!xorMode || bothModes) {
-			/* Copy mode */
-			strcpy (label, test[i].label);
-			ProcessTest(&xparms, &test[i], GXcopy, label);
-		    }
-		    if (xorMode || bothModes) {
-			/* Xor mode */
-			sprintf(label, "(XOR) %s", test[i].label);
-			ProcessTest(&xparms, &test[i], GXxor, label);
-		    }
+		case ROP:
+		    /* Run it through all specified rops and planemasks */
+		    for (rop = 0; rop < numRops; rop++) {
+			for (pm = 0; pm < numPlanemasks; pm++) {
+			    if (planemasks[pm] == ~0) {
+				if (rops[rop] == GXcopy) {
+				    sprintf (label, "%s", test[i].label);
+				} else {
+				    sprintf (label, "(%s) %s",
+					ropNames[rops[rop]].name,
+					test[i].label);
+				}
+			    } else {
+				sprintf (label, "(%s 0x%x) %s",
+					ropNames[rops[rop]].name,
+					planemasks[pm],
+					test[i].label);
+			    }
+			    ProcessTest(&xparms, &test[i], rops[rop],
+				        planemasks[pm], label);
+			} /* for pm */
+		    } /* for rop */
 		    break;
 		
 		case WINDOW:
 		    /* Loop through number of children array */
-		    for (child = 0; subs[child] != 0; child++) {
-			test[i].parms.objects = subs[child];
+		    for (child = 0; child != numSubWindows; child++) {
+			test[i].parms.objects = subWindows[child];
 			sprintf(label, "%s (%d kids)",
 			    test[i].label, test[i].parms.objects);
-			ProcessTest(&xparms, &test[i], GXcopy, label);
+			ProcessTest(&xparms, &test[i], GXcopy, ~0, label);
 		    }
 		    break;
 	    } /* switch */
@@ -905,5 +1087,109 @@ main(argc, argv)
     /* Restore ScreenSaver to original state. */
     XSetScreenSaver(xparms.d, ssTimeout, ssInterval, ssPreferBlanking,
 	ssAllowExposures);
+    XCloseDisplay(xparms.d);
 }
 
+int
+GetWords (argi, argc, argv, wordsp, nump)
+    int     argi;
+    int     argc;
+    char    **argv;
+    char    **wordsp;
+    int     *nump;
+{
+    int	    count;
+
+    if (argc <= argi)
+	usage();
+    count = 0;
+    while (argv[argi] && *(argv[argi]) != '-') {
+	*wordsp++ = argv[argi];
+	++argi;
+	count++;
+    }
+    *nump = count;
+    return count;
+}
+
+int atox (s)
+    char    *s;
+{
+    int     v, c;
+
+    v = 0;
+    while (*s) {
+	if ('0' <= *s && *s <= '9')
+	    c = *s - '0';
+	else if ('a' <= *s && *s <= 'f')
+	    c = *s - 'a' + 10;
+	else if ('A' <= *s && *s <= 'F')
+	    c = *s - 'A' + 10;
+	v = v * 16 + c;
+	s++;
+    }
+    return v;
+}
+
+int GetNumbers (argi, argc, argv, intsp, nump)
+    int     argi;
+    int     argc;
+    char    **argv;
+    int     *intsp;
+    int     *nump;
+{
+    char    *words[256];
+    int	    count;
+    int	    i;
+    int	    flip;
+
+    count = GetWords (argi, argc, argv, words, nump);
+    for (i = 0; i < count; i++) {
+	flip = 0;
+	if (!strncmp (words[i], "~", 1)) {
+	    words[i]++;
+	    flip = ~0;
+	}
+	if (!strncmp (words[i], "0x", 2))
+	    intsp[i] = atox(words[i] + 2) ^ flip;
+	else
+	    intsp[i] = atoi (words[i]) ^ flip;
+    }
+    return count;
+}
+
+GetRops (argi, argc, argv, ropsp, nump)
+    int     argi;
+    int     argc;
+    char    **argv;
+    int     *ropsp;
+    int     *nump;
+{
+    char    *words[256];
+    int	    count;
+    int	    i;
+    int	    rop;
+
+    count = GetWords (argi, argc, argv, words, nump);
+    for (i = 0; i < count; i++) {
+	if (!strncmp (words[i], "GX", 2))
+	    words[i] += 2;
+	if (!strcmp (words[i], "all")) {
+	    for (i = 0; i < 16; i++)
+		ropsp[i] = ropNames[i].rop;
+	    *nump = 16;
+	    break;
+	}
+	for (rop = 0; rop < 16; rop++) {
+	    if (!strcmp (words[i], ropNames[rop].name)) {
+		ropsp[i] = ropNames[rop].rop;
+		break;
+	    }
+	}
+	if (rop == 16) {
+	    fprintf (stderr, "unknown rop name %s\n", words[i]);
+	    usage ();
+	}
+    }
+    return count;
+}
